#!/usr/bin/python3
import os
import sys
import argparse
import subprocess

def do_build(optee, bl33):
    destdir = 'build/qemu/debug'
    cmdline = [
        'make',
        'V=1',
        'CROSS_COMPILE=aarch64-linux-gnu-',
        'DEBUG=1',
        'LOG_LEVEL=40',

        'PLAT=qemu',
        'QEMU_USE_GIC_DRIVER=QEMU_GICV2',

        'ENABLE_SVE_FOR_NS=1',
        'ENABLE_SVE_FOR_SWD=1',
        'ENABLE_SME_FOR_NS=1',
        'ENABLE_SME_FOR_SWD=1',
        'BL32_RAM_LOCATION=tdram',
        'SPD=opteed',

        f'BL32={optee}/tee-header_v2.bin',
        f'BL32_EXTRA1={optee}/tee-pager_v2.bin',
        f'BL32_EXTRA2={optee}/tee-pageable_v2.bin',

        f'BL33={bl33}',

        'all', 'fip',
    ]
    print(cmdline, flush = True)
    subprocess.run(cmdline, check = True)

def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('--optee', dest = 'optee', type = str, metavar = 'DIR',
                        default = '/usr/share/optee_os/qemu-bare')
    parser.add_argument('--bl33', dest = 'bl33', type = str, metavar = 'FILE',
                        default = '/usr/share/edk2/aarch64/QEMU_EFI.kernel.fd')
    options = parser.parse_args()

    do_build(options.optee, options.bl33)

if __name__ == '__main__':
    sys.exit(main())
